@@ -15,11 +15,19 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Py6S.  If not, see <http://www.gnu.org/licenses/>.
 
+import sys
+from datetime import timezone
+
 import dateutil.parser
 
+from ..sixs_exceptions import ParameterError
+
+# Fix for Python 3 where long is not available
+if sys.version_info[0] >= 3:
+    long = int
+
 
 class Geometry:
-
     class User:
 
         """Stores parameters for a user-defined geometry for 6S.
@@ -43,39 +51,53 @@ class Geometry:
         month = 1
 
         def __str__(self):
-            return '0 (User defined)\n%f %f %f %f %d %d\n' % (self.solar_z, self.solar_a, self.view_z, self.view_a, self.month, self.day)
+            return "0 (User defined)\n%f %f %f %f %d %d\n" % (
+                self.solar_z,
+                self.solar_a,
+                self.view_z,
+                self.view_a,
+                self.month,
+                self.day,
+            )
 
-        def from_time_and_location(self, lat, long, datetimestring, view_z, view_a):
-            """Sets the user-defined geometry to a given view zenith and azimuth, and a solar zenith and azimuth calculated from the lat, long and date given.
+        def from_time_and_location(self, lat, lon, datetimestring, view_z, view_a):
+            """Sets the user-defined geometry to a given view zenith and azimuth, and a solar zenith and azimuth calculated from the lat, lon and datetime given.
 
-            Uses the PySolar module for the calculations.
+            Uses the pysolar module for the calculations.
 
             Arguments:
 
             * ``lat`` -- The latitude of the location (0-90 degrees)
-            * ``long`` -- The longitude of the location
-            * ``datetimestring`` -- Any string that can be parsed to produce a date/time object. All that is really needed is a time - eg. "14:53"
+            * ``lon`` -- The longitude of the location
+            * ``datetimestring`` -- A date-time string in ISO format (eg. "2018-06-14 11:37"). This must be in UTC.
             * ``view_z`` -- The view zenith angle
             * ``view_a`` -- The view azimuth angle
 
             """
-            # Try and import the PySolar module, if it fails give an error message
+            # Try and import the pysolar module, if it fails give an error message
             try:
-                import Pysolar
-            except:
-                raise ImportError("To set the geometry from a time and location you must have the PySolar module installed.\nTo install this, run 'pip install pysolar' at the command line.")
+                import pysolar
+            except ImportError:
+                raise ImportError(
+                    "To set the geometry from a time and location you must have the pysolar module installed.\nPy6S requires Pysolar v0.9 or later.\nTo install this, run 'pip install pysolar==0.6' at the command line."
+                )
 
-            dt = dateutil.parser.parse(datetimestring, dayfirst=True)
-            self.solar_z = 90.0 - Pysolar.GetAltitude(lat, long, dt)
+            try:
+                dt = dateutil.parser.isoparse(datetimestring)
+            except ValueError:
+                raise ParameterError(
+                    "datetime",
+                    "You must pass a date-time in ISO 8601 format - ie. YYYY-MM-DD HH:MM:SS",
+                )
 
-            az = Pysolar.GetAzimuth(lat, long, dt)
+            dt = dt.replace(tzinfo=timezone.utc)
 
-            if az < 0:
-                self.solar_a = abs(az) + 180
-            else:
-                self.solar_a = abs(az - 180)
+            alt = pysolar.solar.get_altitude(lat, lon, dt)
+            self.solar_z = 90.0 - alt
 
-            self.solar_a = self.solar_a % 360
+            az = pysolar.solar.get_azimuth(lat, lon, dt)
+
+            self.solar_a = az % 360
 
             self.day = dt.day
             self.month = dt.month
@@ -104,7 +126,13 @@ class Geometry:
         line = 0
 
         def __str__(self):
-            return '1 (Meteosat)\n%d %d %f %d %d (Geometrical Conditions)\n' % (self.month, self.day, self.gmt_decimal_hour, self.column, self.line)
+            return "1 (Meteosat)\n%d %d %f %d %d (Geometrical Conditions)\n" % (
+                self.month,
+                self.day,
+                self.gmt_decimal_hour,
+                self.column,
+                self.line,
+            )
 
     class GoesEast:
 
@@ -119,6 +147,7 @@ class Geometry:
          * ``line`` -- The GOES East line of the image
 
         """
+
         month = 1
         day = 1
         gmt_decimal_hour = 0
@@ -126,7 +155,13 @@ class Geometry:
         line = 0
 
         def __str__(self):
-            return '2 (Goes East)\n%d %d %f %d %d (Geometrical Conditions)\n' % (self.month, self.day, self.gmt_decimal_hour, self.column, self.line)
+            return "2 (Goes East)\n%d %d %f %d %d (Geometrical Conditions)\n" % (
+                self.month,
+                self.day,
+                self.gmt_decimal_hour,
+                self.column,
+                self.line,
+            )
 
     class GoesWest:
 
@@ -141,6 +176,7 @@ class Geometry:
          * ``line`` -- The GOES West line of the image
 
         """
+
         month = 1
         day = 1
         gmt_decimal_hour = 0
@@ -148,7 +184,13 @@ class Geometry:
         line = 0
 
         def __str__(self):
-            return '3 (Goes West)\n%d %d %f %d %d (Geometrical Conditions)\n' % (self.month, self.day, self.gmt_decimal_hour, self.column, self.line)
+            return "3 (Goes West)\n%d %d %f %d %d (Geometrical Conditions)\n" % (
+                self.month,
+                self.day,
+                self.gmt_decimal_hour,
+                self.column,
+                self.line,
+            )
 
     class AVHRR_PM:
 
@@ -163,6 +205,7 @@ class Geometry:
          * ``ascendant_node_hour`` -- The hour of the ascendant node of the image
 
         """
+
         month = 1
         day = 1
         gmt_decimal_hour = 0
@@ -171,7 +214,14 @@ class Geometry:
         ascendant_node_hour = 0
 
         def __str__(self):
-            return '4 (AVHRR PM NOAA)\n%d %d %d %f %f (Geometrical Conditions)\n' % (self.month, self.day, self.gmt_decimal_hour, self.column, self.ascendant_node_longitude, self.ascendant_node_hour)
+            return "4 (AVHRR PM NOAA)\n%d %d %d %f %f (Geometrical Conditions)\n" % (
+                self.month,
+                self.day,
+                self.gmt_decimal_hour,
+                self.column,
+                self.ascendant_node_longitude,
+                self.ascendant_node_hour,
+            )
 
     class AVHRR_AM:
 
@@ -186,6 +236,7 @@ class Geometry:
          * ``ascendant_node_hour`` -- The hour of the ascendant node of the image
 
         """
+
         month = 1
         day = 1
         gmt_decimal_hour = 0
@@ -194,7 +245,14 @@ class Geometry:
         ascendant_node_hour = 0
 
         def __str__(self):
-            return '5 (AVHRR AM NOAA)\n%d %d %d %f %f (Geometrical Conditions)\n' % (self.month, self.day, self.gmt_decimal_hour, self.column, self.ascendant_node_longitude, self.ascendant_node_hour)
+            return "5 (AVHRR AM NOAA)\n%d %d %d %f %f (Geometrical Conditions)\n" % (
+                self.month,
+                self.day,
+                self.gmt_decimal_hour,
+                self.column,
+                self.ascendant_node_longitude,
+                self.ascendant_node_hour,
+            )
 
     class SPOT_HRV:
 
@@ -209,6 +267,7 @@ class Geometry:
          * ``longitude`` -- The longitude of the centre of the image
 
         """
+
         month = 1
         day = 1
         gmt_decimal_hour = 0
@@ -216,7 +275,13 @@ class Geometry:
         latitude = 0
 
         def __str__(self):
-            return '6 (SPOT)\n%d %d %f %f %f (Geometrical Conditions)\n' % (self.month, self.day, self.gmt_decimal_hour, self.longitude, self.latitude)
+            return "6 (SPOT)\n%d %d %f %f %f (Geometrical Conditions)\n" % (
+                self.month,
+                self.day,
+                self.gmt_decimal_hour,
+                self.longitude,
+                self.latitude,
+            )
 
     class Landsat_TM:
 
@@ -231,6 +296,7 @@ class Geometry:
          * ``longitude`` -- The longitude of the centre of the image
 
         """
+
         month = 1
         day = 1
         gmt_decimal_hour = 0
@@ -238,4 +304,10 @@ class Geometry:
         latitude = 0
 
         def __str__(self):
-            return '7 (TM)\n%d %d %f %f %f (Geometrical Conditions)\n' % (self.month, self.day, self.gmt_decimal_hour, self.longitude, self.latitude)
+            return "7 (TM)\n%d %d %f %f %f (Geometrical Conditions)\n" % (
+                self.month,
+                self.day,
+                self.gmt_decimal_hour,
+                self.longitude,
+                self.latitude,
+            )
