@@ -15,20 +15,25 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Py6S.  If not, see <http://www.gnu.org/licenses/>.
 
-from .sixs_exceptions import *
-__all__ = ["SixS", "Outputs", "ParameterError", "OutputParsingError", "ExecutionError"]
-
-from . import Params
-__all__ += ["Params"]
-
-from .Params import *
-__all__ += Params.__all__
-
-from .sixs import SixS
+from . import Params, SixSHelpers
 from .outputs import Outputs
+from .Params import (  # noqa
+    AeroProfile,
+    Altitudes,
+    AtmosCorr,
+    AtmosProfile,
+    Geometry,
+    GroundReflectance,
+    PredefinedWavelengths,
+    Wavelength,
+)
+from .sixs import SixS
+from .sixs_exceptions import ExecutionError, OutputParsingError, ParameterError
+from .SixSHelpers import Aeronet, Angles, Radiosonde, Spectra, Wavelengths  # noqa
 
-from . import SixSHelpers
+__all__ = ["SixS", "Outputs", "ParameterError", "OutputParsingError", "ExecutionError"]
+__all__ += ["Params"]
 __all__ += ["SixSHelpers"]
 
-from .SixSHelpers import *
+__all__ += Params.__all__
 __all__ += SixSHelpers.__all__
